@@ -1,9 +1,7 @@
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
-from django.utils.encoding import python_2_unicode_compatible
+from django.utils.translation import gettext_lazy as _
 
 
-# @python_2_unicode_compatible
 # class MyModel(models.Model):
 #
 #     title = models.CharField(_('Title'), max_length=100, help_text=_('Description'))
