@@ -1,6 +1,6 @@
 {% extends parent_template %}
 
-{% block entry_points %}
+{% block entry_points %}{{ super() }}
         'console_scripts': ['{{ module_name }} = {{ module_name }}.manage:main'],
 {% endblock %}
 
